starcluster.progressbar

Package starcluster :: Module progressbar |
[hide private]
[frames] | no frames]

# Module progressbar

source code

    Text progressbar library for python.

    This library provides a text mode progressbar. This is typically used
    to display the progress of a long running operation, providing a
    visual clue that processing is underway.

    The ProgressBar class manages the progress, and the format of the line
    is given by a number of widgets. A widget is an object that may
    display diferently depending on the state of the progress. There are
    three types of widget:
    - a string, which always shows itself;
    - a ProgressBarWidget, which may return a diferent value every time
    it's update method is called; and
    - a ProgressBarWidgetHFill, which is like ProgressBarWidget, except it
    expands to fill the remaining width of the line.

    The progressbar module is very easy to use, yet very powerful. And
    automatically supports features like auto-resizing when available.

Version: 2.2

Date: 2006-05-07

Author: Nilton Volpato

Classes | [hide private]
| ProgressBarWidget This is an element of ProgressBar formatting.
| ProgressBarWidgetHFill This is a variable width element of ProgressBar formatting.
| ETA Widget for the Estimated Time of Arrival
| FileTransferSpeed Widget for showing the transfer speed (useful for file transfers).
| RotatingMarker A rotating marker for filling the bar of progress.
| Percentage Just the percentage done.
| Fraction Just the fraction done.
| Bar The bar of progress.
| ReverseBar The reverse bar of progress, or bar of regress.
| ProgressBar This is the ProgressBar class, it updates and prints the bar.

Functions | [hide private]
example1() | source code
example2() | source code
example3() | source code
example4() | source code
example5() | source code
main() | source code

Variables | [hide private]
| __author_email__ = ``'``first-name dot last-name @ gmail.com``'``
| default_widgets = `default_widgets`
| __package__ = ``'``starcluster``'``